@@ -22,7 +22,7 @@ minimaxApprox <- function(fn, lower, upper, degree, relErr = FALSE,
 
   if ("conviter" %in% nopts) {
     # If actually passed then overwrite both maxiter and miniter if conviter is
-    # greather than either one.
+    # greater than either one.
     opts$maxiter <- max(opts$maxiter, opts$conviter)
     opts$miniter <- max(opts$miniter, opts$conviter)
   } else {
@@ -91,44 +91,46 @@ minimaxApprox <- function(fn, lower, upper, degree, relErr = FALSE,
   # allow the polynomial algorithm to try degree n + 1 if it fails due to
   # singular error in degree n. IF the resulting highest coefficient contributes
   # less than opts$tailtol to the result then consider it 0 and return the
-  # resulting degree n and message appropriately.
+  # resulting degree n and message appropriately. For rational approximation or
+  # if the error is not a simpleError or does not contain the word "singular",
+  # let the default R failure message come through.
+  #
+  # TODO: Trap other errors with better messages (AA: 2025-12-24)
 
-  if (!ratApprox && inherits(mmA, "simpleError")) {
-    if (grepl("singular", mmA$message, fixed = TRUE)) { # nolint unnecessary_nested_if_linter
-      if (!is.null(opts$tailtol)) { # May be different error
-        mmA <- tryCatch(remPoly(fn, lower, upper, as.integer(degree + 1L),
-                                relErr, basis, opts),
-                        error = function(e) simpleError(trimws(e$message)))
-        if (inherits(mmA, "simpleError")) {
-          stop("The algorithm neither converged when looking for a polynomial",
-               " of length ", degree, " nor when looking for a polynomial of",
-               " degree ", degree + 1L, ".")
-        } else {
-          xmax <- max(abs(lower), abs(upper))
-          n <- length(mmA$a)
-          if ((mmA$a[n] * xmax ^ (n - 1L)) <= opts$tailtol) {
-            mess <- paste("The algorithm failed while looking for a polynomial",
-                          "of degree", degree, "but successfully completed",
-                          "when looking for a polynomial of degree",
-                          degree + 1L, "with the largest coefficient's",
-                          "contribution to the approximation <= the tailtol",
-                          "option. The result is a polynomial of length",
-                          degree, "as the uppermost coefficient is effectively",
-                          "0.")
-            mmA$a <- mmA$a[-n]
-            message(mess)
-          } else {
-            stop("The algorithm did not converge when looking for a polynomial",
-                 " of length ", degree, " and when looking for a polynomial of",
-                 " degree ", degree + 1L, " the uppermost coefficient is not",
-                 " effectively zero.")
-          }
-        }
-      } else {
-        stop("The algorithm did not converge when looking for a polynomial of ",
-             "degree ", degree, " and NULL was passed to the tailtol option.")
-      }
+
+  if (!ratApprox && inherits(mmA, "simpleError") &&
+      grepl("singular", mmA$message, fixed = TRUE)) {
+
+    if (is.null(opts$tailtol)) {
+      stop("The algorithm did not converge when looking for a polynomial of ",
+           "degree ", degree, " and NULL was passed to the tailtol option.")
     }
+
+    mmA <- tryCatch(remPoly(fn, lower, upper, as.integer(degree + 1L),
+                            relErr, basis, opts),
+                    error = function(e) simpleError(trimws(e$message)))
+
+    if (inherits(mmA, "simpleError")) {
+      stop("The algorithm neither converged when looking for a polynomial of",
+      " length ", degree, " nor when looking for a polynomial of degree ",
+      degree + 1L, ".")
+    }
+
+    xmax <- max(abs(lower), abs(upper))
+    n <- length(mmA$a)
+    if ((mmA$a[n] * xmax ^ (n - 1L)) > opts$tailtol) {
+      stop("The algorithm did not converge when looking for a polynomial of",
+           " length ", degree, " and when looking for a polynomial of degree ",
+           degree + 1L, " the uppermost coefficient is not effectively zero.")
+    }
+
+    mmA$a <- mmA$a[-n]
+    message("The algorithm failed while looking for a polynomial of degree ",
+            degree, " but successfully completed when looking for a polynomial",
+            " of degree ", degree + 1L, " with the largest coefficient's",
+            " contribution to the approximation <= the tailtol option. The",
+            " result is a polynomial of length ", degree, " as the uppermost",
+            " coefficient is effectively 0.")
   }
 
   # Handle all warnings centrally.
@@ -166,7 +168,7 @@ minimaxApprox <- function(fn, lower, upper, degree, relErr = FALSE,
     gotWarning <- TRUE
   }
 
-  coefficients <- if (ratApprox) {
+  coeff <- if (ratApprox) {
     list(a = mmA$a, b = mmA$b)
   } else {
     list(a = mmA$a)
@@ -187,7 +189,7 @@ minimaxApprox <- function(fn, lower, upper, degree, relErr = FALSE,
 
   diagnostics <- list(ExpErr = mmA$expe, ObsErr = mmA$mxae, iterations = mmA$i,
                       Extrema = mmA$x, Warning = gotWarning)
-  ret <- c(coefficients, monomialEq, diagnostics)
+  ret <- c(coeff, monomialEq, diagnostics)
   attr(ret, "type") <- if (ratApprox) "Rational" else "Polynomial"
   attr(ret, "basis") <- polynomalBasis
   attr(ret, "func") <- fn
@@ -219,14 +221,12 @@ minimaxEval <- function(x, mmA, basis = "Chebyshev") {
     } else {
       evalFunc(x, mmA, "c")
     }
-  } else {
-    if (onlyMono) {
+  } else if (onlyMono) {
       evalFunc(x, mmA, "m")
-    } else {
-      RR <- list(a = mmA$aMono)
-      if ("bMono" %in% names(mmA)) RR <- c(RR, list(b = mmA$bMono))
-      evalFunc(x, RR, "m")
-    }
+  } else {
+    RR <- list(a = mmA$aMono)
+    if ("bMono" %in% names(mmA)) RR <- c(RR, list(b = mmA$bMono))
+    evalFunc(x, RR, "m")
   }
 }
 
