@@ -12,16 +12,16 @@
 // variables need to be initialized as "volatile" as we specifically DO NOT WANT
 // the compiler to optimize them out (z to a for example). The entire point of
 // EFT algorithms is to capture the floating-point error as best possible!
-double twoSumy(double a, double b) {
-  volatile double x = a + b;
-  volatile double z = x - a;
+volatile long double twoSumy(long double a, long double b) {
+  volatile long double x = a + b;
+  volatile long double z = x - a;
   return((a - (x - z)) + (b - z));
 }
 
 // This is the y component of twoProdFMA; the x component is the product itself.
-double twoProdFMAy(double a, double b) {
-  double x = a * b;
-  return(fma(a, b, -x));
+volatile long double twoProdFMAy(long double a, long double b) {
+  long double x = a * b;
+  return(fmal(a, b, -x));
 }
 
 // Compensated Horner method combining the Error-Free Transformation component
@@ -57,25 +57,36 @@ extern SEXP compHorner_c(SEXP x, SEXP a) {
   // Once the inner loop finishes, so too is the correction for that x, so it
   // applied at the end of the outer loop. Now only one nested loop is needed.
 
+  // Create auxiliary long double variables (ending in l) to leverage internal
+  // functions at higher precision and only demote to double when populating
+  // the SEXP return object. (AA: 2025-12-25)
+
   if (n > 1) {
-    double Ax;
-    double pi;
-    double sigma;
-    double correction;
+    long double Ax;
+    long double pi;
+    long double sigma;
+    long double correction;
+    long double pretl;
+    long double pxl;
+    long double pal;
 
     for (int i = 0; i < m; ++i) {
-      correction = 0.0;
+      correction = 0.0L;
+      pretl = (long double)pret[i];
+      pxl = (long double)px[i];
       for (int j = nm1; j-- > 0; ) {
         // Error-Free-Transformation (EFT) Horner
-        Ax = pret[i] * px[i];
-        pi = twoProdFMAy(pret[i], px[i]);
-        pret[i] = Ax + pa[j];
-        sigma = twoSumy(Ax, pa[j]);
+        pal = (long double)pa[j];
+        Ax = pretl * pxl;
+        pi = twoProdFMAy(pretl, pxl);
+        pretl = Ax + pal;
+        sigma = twoSumy(Ax, pal);
         // Horner Sum correction
-        correction *= px[i];
+        correction *= pxl;
         correction += pi + sigma;
       }
-      pret[i] += correction;
+      pretl += correction;
+      pret[i] = (double)pretl;
     }
   }
 
